pub struct Pagination<Cursor = Ulid> {
pub before: Option<Cursor>,
pub after: Option<Cursor>,
pub count: usize,
pub direction: PaginationDirection,
}Expand description
Pagination parameters
Fields
before: Option<Cursor>The cursor to start from
after: Option<Cursor>The cursor to end at
count: usizeThe maximum number of items to return
direction: PaginationDirectionIn which direction to paginate
Implementations
Sourceimpl<C> Pagination<C>
impl<C> Pagination<C>
Sourcepub fn try_new(
before: Option<C>,
after: Option<C>,
first: Option<usize>,
last: Option<usize>,
) -> Result<Self, InvalidPagination>
pub fn try_new( before: Option<C>, after: Option<C>, first: Option<usize>, last: Option<usize>, ) -> Result<Self, InvalidPagination>
Creates a new Pagination from user-provided parameters.
Errors
Either first or last must be provided, else this function will
return an InvalidPagination error.
Sourcepub const fn first(first: usize) -> Self
pub const fn first(first: usize) -> Self
Creates a Pagination which gets the first N items
Sourcepub const fn last(last: usize) -> Self
pub const fn last(last: usize) -> Self
Creates a Pagination which gets the last N items
Sourcepub fn clear_before(self) -> Self
pub fn clear_before(self) -> Self
Clear the before cursor
Sourcepub fn clear_after(self) -> Self
pub fn clear_after(self) -> Self
Clear the after cursor