pub enum PersonalSessionState {
Active,
Revoked,
}Expand description
Filter for what state a personal session is in.
Variants
Active
The personal session is active, which means it either has active access tokens or can have new access tokens generated.
Revoked
The personal session is revoked, which means no more access tokens can be generated and none are active.