pub struct PersonalSessionFilter<'a> { /* private fields */ }Expand description
Filter parameters for listing personal sessions alongside personal access tokens
Implementations
Sourceimpl<'a> PersonalSessionFilter<'a>
impl<'a> PersonalSessionFilter<'a>
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new PersonalSessionFilter with default values
Sourcepub fn for_owner_user(self, user: &'a User) -> Self
pub fn for_owner_user(self, user: &'a User) -> Self
List sessions owned by a specific user
Sourcepub fn owner_oauth2_client(&self) -> Option<&'a Client>
pub fn owner_oauth2_client(&self) -> Option<&'a Client>
Get the owner user filter
Returns None if no user filter was set
Sourcepub fn for_owner_oauth2_client(self, client: &'a Client) -> Self
pub fn for_owner_oauth2_client(self, client: &'a Client) -> Self
List sessions owned by a specific user
Sourcepub fn owner_user(&self) -> Option<&'a User>
pub fn owner_user(&self) -> Option<&'a User>
Get the owner user filter
Returns None if no user filter was set
Sourcepub fn for_actor_user(self, user: &'a User) -> Self
pub fn for_actor_user(self, user: &'a User) -> Self
List sessions acting as a specific user
Sourcepub fn actor_user(&self) -> Option<&'a User>
pub fn actor_user(&self) -> Option<&'a User>
Get the actor user filter
Returns None if no user filter was set
Sourcepub fn with_last_active_before(self, last_active_before: DateTime<Utc>) -> Self
pub fn with_last_active_before(self, last_active_before: DateTime<Utc>) -> Self
Only return sessions with a last active time before the given time
Sourcepub fn with_last_active_after(self, last_active_after: DateTime<Utc>) -> Self
pub fn with_last_active_after(self, last_active_after: DateTime<Utc>) -> Self
Only return sessions with a last active time after the given time
Sourcepub fn last_active_before(&self) -> Option<DateTime<Utc>>
pub fn last_active_before(&self) -> Option<DateTime<Utc>>
Get the last active before filter
Returns None if no client filter was set
Sourcepub fn last_active_after(&self) -> Option<DateTime<Utc>>
pub fn last_active_after(&self) -> Option<DateTime<Utc>>
Get the last active after filter
Returns None if no client filter was set
Sourcepub fn active_only(self) -> Self
pub fn active_only(self) -> Self
Only return active sessions
Sourcepub fn finished_only(self) -> Self
pub fn finished_only(self) -> Self
Only return finished sessions
Sourcepub fn state(&self) -> Option<PersonalSessionState>
pub fn state(&self) -> Option<PersonalSessionState>
Get the state filter
Returns None if no state filter was set
Sourcepub fn with_scope(self, scope: &'a Scope) -> Self
pub fn with_scope(self, scope: &'a Scope) -> Self
Only return sessions with the given scope
Sourcepub fn scope(&self) -> Option<&'a Scope>
pub fn scope(&self) -> Option<&'a Scope>
Get the scope filter
Returns None if no scope filter was set
Sourcepub fn for_device(self, device: &'a Device) -> Self
pub fn for_device(self, device: &'a Device) -> Self
Only return sessions that have the given device in their scope
Sourcepub fn device(&self) -> Option<&'a Device>
pub fn device(&self) -> Option<&'a Device>
Get the device filter
Returns None if no device filter was set
Sourcepub fn with_expires_before(self, expires_before: DateTime<Utc>) -> Self
pub fn with_expires_before(self, expires_before: DateTime<Utc>) -> Self
Only return sessions whose access tokens expire before the given time
Sourcepub fn expires_before(&self) -> Option<DateTime<Utc>>
pub fn expires_before(&self) -> Option<DateTime<Utc>>
Get the expires before filter
Returns None if no expires before filter was set
Sourcepub fn with_expires_after(self, expires_after: DateTime<Utc>) -> Self
pub fn with_expires_after(self, expires_after: DateTime<Utc>) -> Self
Only return sessions whose access tokens expire after the given time
Sourcepub fn expires_after(&self) -> Option<DateTime<Utc>>
pub fn expires_after(&self) -> Option<DateTime<Utc>>
Get the expires after filter
Returns None if no expires after filter was set
Sourcepub fn with_expires(self, expires: bool) -> Self
pub fn with_expires(self, expires: bool) -> Self
Only return sessions whose access tokens have, or don’t have, an expiry time set