pub trait InsertableJob: Serialize + Send {
const QUEUE_NAME: &'static str;
}Expand description
A trait that represents a job which can be inserted into a queue
Required Associated Constants
Sourceconst QUEUE_NAME: &'static str
const QUEUE_NAME: &'static str
The name of the queue this job belongs to
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".