MapErr

Struct MapErr 

pub struct MapErr<R, F> { /* private fields */ }
A wrapper which is used to map the error type of a repository to another

Implementations

Source

impl<R, F> MapErr<R, F>

pub fn new(inner: R, mapper: F) -> Self

Create a new MapErr wrapper from an inner repository and a mapper function