UserFilter

Struct UserFilter 

pub struct UserFilter<'a> { /* private fields */ }
Filter parameters for listing users

Implementations

Source

impl<'a> UserFilter<'a>

pub fn new() -> Self

Create a new UserFilter with default values

pub fn active_only(self) -> Self

Filter for active users

pub fn locked_only(self) -> Self

Filter for locked users

pub fn deactivated_only(self) -> Self

Filter for deactivated users

pub fn can_request_admin_only(self) -> Self

Filter for users that can request admin privileges

pub fn cannot_request_admin_only(self) -> Self

Filter for users that can’t request admin privileges

pub fn guest_only(self) -> Self

Filter for guest users

pub fn non_guest_only(self) -> Self

Filter for non-guest users

Filter for users that match the given search string

pub fn state(&self) -> Option<UserState>

Get the state filter

Returns None if no state filter was set

pub fn can_request_admin(&self) -> Option<bool>

Get the can request admin filter

Returns None if no can request admin filter was set

pub fn is_guest(&self) -> Option<bool>

Get the is guest filter

Returns None if no is guest filter was set

pub fn search(&self) -> Option<&'a str>

Get the search filter

Returns None if no search filter was set