pub struct UpstreamOAuthProviderParams {Show 23 fields
pub issuer: Option<String>,
pub human_name: Option<String>,
pub brand_name: Option<String>,
pub scope: Scope,
pub token_endpoint_auth_method: UpstreamOAuthProviderTokenAuthMethod,
pub token_endpoint_signing_alg: Option<JsonWebSignatureAlg>,
pub id_token_signed_response_alg: JsonWebSignatureAlg,
pub fetch_userinfo: bool,
pub userinfo_signed_response_alg: Option<JsonWebSignatureAlg>,
pub client_id: String,
pub encrypted_client_secret: Option<String>,
pub claims_imports: UpstreamOAuthProviderClaimsImports,
pub authorization_endpoint_override: Option<Url>,
pub token_endpoint_override: Option<Url>,
pub userinfo_endpoint_override: Option<Url>,
pub jwks_uri_override: Option<Url>,
pub discovery_mode: UpstreamOAuthProviderDiscoveryMode,
pub pkce_mode: UpstreamOAuthProviderPkceMode,
pub response_mode: Option<UpstreamOAuthProviderResponseMode>,
pub additional_authorization_parameters: Vec<(String, String)>,
pub forward_login_hint: bool,
pub ui_order: i32,
pub on_backchannel_logout: UpstreamOAuthProviderOnBackchannelLogout,
}Expand description
Structure which holds parameters when inserting or updating an upstream OAuth 2.0 provider
Fields
issuer: Option<String>The OIDC issuer of the provider
human_name: Option<String>A human-readable name for the provider
brand_name: Option<String>A brand identifier, e.g. “apple” or “google”
scope: ScopeThe scope to request during the authorization flow
token_endpoint_auth_method: UpstreamOAuthProviderTokenAuthMethodThe token endpoint authentication method
token_endpoint_signing_alg: Option<JsonWebSignatureAlg>The JWT signing algorithm to use when then client_secret_jwt or
private_key_jwt authentication methods are used
id_token_signed_response_alg: JsonWebSignatureAlgExpected signature for the JWT payload returned by the token authentication endpoint.
Defaults to RS256.
fetch_userinfo: boolWhether to fetch the user profile from the userinfo endpoint,
or to rely on the data returned in the id_token from the
token_endpoint.
userinfo_signed_response_alg: Option<JsonWebSignatureAlg>Expected signature for the JWT payload returned by the userinfo endpoint.
If not specified, the response is expected to be an unsigned JSON
payload. Defaults to None.
client_id: StringThe client ID to use when authenticating to the upstream
encrypted_client_secret: Option<String>The encrypted client secret to use when authenticating to the upstream
claims_imports: UpstreamOAuthProviderClaimsImportsHow claims should be imported from the upstream provider
The URL to use as the authorization endpoint. If None, the URL will be
discovered
token_endpoint_override: Option<Url>The URL to use as the token endpoint. If None, the URL will be
discovered
userinfo_endpoint_override: Option<Url>The URL to use as the userinfo endpoint. If None, the URL will be
discovered
jwks_uri_override: Option<Url>The URL to use when fetching JWKS. If None, the URL will be discovered
discovery_mode: UpstreamOAuthProviderDiscoveryModeHow the provider metadata should be discovered
pkce_mode: UpstreamOAuthProviderPkceModeHow should PKCE be used
response_mode: Option<UpstreamOAuthProviderResponseMode>What response mode it should ask
Additional parameters to include in the authorization request
forward_login_hint: boolWhether to forward the login hint to the upstream provider.
ui_order: i32The position of the provider in the UI
on_backchannel_logout: UpstreamOAuthProviderOnBackchannelLogoutThe behavior when receiving a backchannel logout notification