pub struct UserFilter<'a> { /* private fields */ }Expand description
Filter parameters for listing users
Implementations
Sourceimpl<'a> UserFilter<'a>
impl<'a> UserFilter<'a>
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new UserFilter with default values
Sourcepub fn active_only(self) -> Self
pub fn active_only(self) -> Self
Filter for active users
Sourcepub fn locked_only(self) -> Self
pub fn locked_only(self) -> Self
Filter for locked users
Sourcepub fn deactivated_only(self) -> Self
pub fn deactivated_only(self) -> Self
Filter for deactivated users
Sourcepub fn can_request_admin_only(self) -> Self
pub fn can_request_admin_only(self) -> Self
Filter for users that can request admin privileges
Sourcepub fn cannot_request_admin_only(self) -> Self
pub fn cannot_request_admin_only(self) -> Self
Filter for users that can’t request admin privileges
Sourcepub fn guest_only(self) -> Self
pub fn guest_only(self) -> Self
Filter for guest users
Sourcepub fn non_guest_only(self) -> Self
pub fn non_guest_only(self) -> Self
Filter for non-guest users
Sourcepub fn matching_search(self, search: &'a str) -> Self
pub fn matching_search(self, search: &'a str) -> Self
Filter for users that match the given search string
Sourcepub fn state(&self) -> Option<UserState>
pub fn state(&self) -> Option<UserState>
Get the state filter
Returns None if no state filter was set
Sourcepub fn can_request_admin(&self) -> Option<bool>
pub fn can_request_admin(&self) -> Option<bool>
Get the can request admin filter
Returns None if no can request admin filter was set